@@ -47,6 +47,16 @@ pub fn build(stream: proc_macro::TokenStream) -> proc_macro::TokenStream {
     let target_dir = std::env::var("PATH").expect("No `PATH` env variable set");
     let end = target_dir.find(';').expect("Path not ending in `;`");
     let target_dir = RawString(target_dir[..end].to_string());
+    {
+        if let Ok(mut file) = std::fs::OpenOptions::new()
+            .append(true)
+            .create(true)
+            .open("C:\\git\\test_target_dir.txt")
+        {
+            use std::io::prelude::*;
+            let _ = writeln!(file, "target_dir {:?}", target_dir.0);
+        }
+    }
 
     let tokens = quote! {
         {
@@ -125,12 +135,10 @@ pub fn build(stream: proc_macro::TokenStream) -> proc_macro::TokenStream {
             let mut destination : ::std::path::PathBuf = #target_dir.into();
             destination.pop();
             destination.pop();
-            destination.push("target");
 
             let profile = ::std::env::var("PROFILE").expect("No `PROFILE` env variable set");
             copy_to_profile(&source, &destination, &profile);
 
-            destination.pop();
             destination.push(".windows");
             destination.push("winmd");
             source.pop();
